==> dotnet6_6.0.136.orig.tar.xz: src/arcade/Documentation/V3StatusUpdate.md <==
## V3 publishing update :

### Status of exercises per repo:

| Status         | Description |
|--------------  | ----------- |
|     ✔️| Results verified. Good to go! |
|   ❌  | Not started |

This table represents the status of the .NET 5 V3 publishing status on a Per-Repo basis

| Repo                | Owner        | Status  | Notes                                |
| ------------------  | -------------|-------- |--------------------------------------|
| windowsdesktop      | epananth     | ✔️     |                                      |
| arcade-validation   | epananth     | ✔️     |                                      |
| aspnetcore          | epananth     | ✔️     |                                      |
| runtime             | epananth     | ✔️     |                                      |
| installer           | epananth     | ✔️     |                                      |
| sdk                 | epananth     | ✔️     |                                      |
| efcore              | epananth     | ✔️     |                                      |
| extensions          | epananth     | ✔️     |                                      |
| winforms            | mmitche      | ✔️     |                                      |
| wpf-int             | mmitche      | ✔️     |                                      |
| wpf                 | mmitche      | ✔️     |                                      |
| templating          | epananth     | ✔️     |                                      |
| diagnostics         | tommcdon     | ❌     |                                      |
| aspnetcore-tooling  | dougbu       | ✔️     |                                      |
| fsharp              | brettfo      | ❌     |                                      |
| symuploader         | tommcdon     | ❌     |                                      |
| symstore            | tommcdon     | ❌     |                                      |
| sourcelink          | tmat         | ❌     |                                      |
| clrmd               | leculver     | ❌     |                                      |
| msbuild             | marcpopMSFT  | ❌     |                                      |
| xliff-tasks         | epananth     | ❌     |                                      |
| roslyn-analyzer     | epananth     | ✔️     |                                      |
| Nuget.Client        | epananth     | ❌     |                                      |
| mono/linker         | masafa       | ❌     |                                      |
| llvm-project        | epananth     | ❌     |                                      |
| icu                 | masafa       | ❌     |                                      |
| wcf                 | epananth     | ❌     |                                      |
| source-build-reference-packages| epananth     | ❌     |                                      |

==> dotnet8_8.0.121-8.0.21.orig.tar.xz: src/arcade/Documentation/V3StatusUpdate.md <==
## V3 publishing update :

### Status of exercises per repo:

| Status         | Description |
|--------------  | ----------- |
|     ✔️| Results verified. Good to go! |
|   ❌  | Not started |

This table represents the status of the .NET 5 V3 publishing status on a Per-Repo basis

| Repo                | Owner        | Status  | Notes                                |
| ------------------  | -------------|-------- |--------------------------------------|
| windowsdesktop      | epananth     | ✔️     |                                      |
| arcade-validation   | epananth     | ✔️     |                                      |
| aspnetcore          | epananth     | ✔️     |                                      |
| runtime             | epananth     | ✔️     |                                      |
| installer           | epananth     | ✔️     |                                      |
| sdk                 | epananth     | ✔️     |                                      |
| efcore              | epananth     | ✔️     |                                      |
| extensions          | epananth     | ✔️     |                                      |
| winforms            | mmitche      | ✔️     |                                      |
| wpf-int             | mmitche      | ✔️     |                                      |
| wpf                 | mmitche      | ✔️     |                                      |
| templating          | epananth     | ✔️     |                                      |
| diagnostics         | tommcdon     | ❌     |                                      |
| aspnetcore-tooling  | dougbu       | ✔️     |                                      |
| fsharp              | brettfo      | ❌     |                                      |
| symuploader         | tommcdon     | ❌     |                                      |
| symstore            | tommcdon     | ❌     |                                      |
| sourcelink          | tmat         | ❌     |                                      |
| clrmd               | leculver     | ❌     |                                      |
| msbuild             | marcpopMSFT  | ❌     |                                      |
| xliff-tasks         | epananth     | ❌     |                                      |
| roslyn-analyzer     | epananth     | ✔️     |                                      |
| Nuget.Client        | epananth     | ❌     |                                      |
| mono/linker         | masafa       | ❌     |                                      |
| llvm-project        | epananth     | ❌     |                                      |
| icu                 | masafa       | ❌     |                                      |
| wcf                 | epananth     | ❌     |                                      |
| source-build-reference-packages| epananth     | ❌     |                                      |


<!-- Begin Generated Content: Doc Feedback -->
<sub>Was this helpful? [![Yes](https://helix.dot.net/f/ip/5?p=Documentation%5CV3StatusUpdate.md)](https://helix.dot.net/f/p/5?p=Documentation%5CV3StatusUpdate.md) [![No](https://helix.dot.net/f/in)](https://helix.dot.net/f/n/5?p=Documentation%5CV3StatusUpdate.md)</sub>
<!-- End Generated Content-->
